@@ -70,15 +70,13 @@ gconf_editor_window_popup_error_dialog (GtkWindow   *parent,
 	dialog = gtk_message_dialog_new (parent,
 					 GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_MESSAGE_ERROR,
-					 GTK_BUTTONS_CLOSE,
+					 GTK_BUTTONS_OK,
 					 message,
 					 error->message);
 	g_error_free (error);
 
-	g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_widget_show (dialog);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 }
 
 static void
@@ -96,13 +94,22 @@ gconf_editor_window_go_to (GConfEditorWindow *window,
 	gint depth;
 	gint i, nchildren;
 	char *key;
-
+	gboolean dir_exists;
+	GError *error = NULL;
+	
 	g_return_if_fail (location != NULL);
-
-	if (!gconf_client_get (window->client, location, NULL) && 
-	    !gconf_client_dir_exists (window->client, location, NULL))
+		
+	dir_exists = gconf_client_dir_exists (window->client, location, &error);
+	
+	if (error != NULL) {
+    		gconf_editor_window_popup_error_dialog (GTK_WINDOW (window),"%s", error);
+        	return;
+	}
+	
+	if (!gconf_client_get (window->client, location, NULL) && !dir_exists)
 		return;
-
+	
+	
 	child_path = gconf_tree_model_get_tree_path_from_gconf_path (
 				GCONF_TREE_MODEL (window->tree_model), location);
 	if (!child_path)
@@ -137,7 +144,7 @@ gconf_editor_window_go_to (GConfEditorWindow *window,
 	gtk_tree_path_free (path);
 
 	/* check for key name in the list model */
-	key = rindex (location, '/');
+	key = strrchr (location, '/');
 	if (!key || strlen (key) < 2)
 		return;
 	key++;
@@ -752,7 +759,7 @@ static GtkActionEntry entries[] = {
 	  G_CALLBACK (gconf_editor_popup_window_new_key) },
 	{ "EditKey", NULL, N_("_Edit Key..."), NULL, N_("Edit the selected key"),
 	  G_CALLBACK (gconf_editor_popup_window_edit_key) },
-	{ "UnsetKey", GTK_STOCK_DELETE, N_("_Unset Key..."), NULL, N_("Unset the selected key"),
+	{ "UnsetKey", GTK_STOCK_DELETE, N_("_Unset Key"), NULL, N_("Unset the selected key"),
 	  G_CALLBACK (gconf_editor_popup_window_unset_key) },
 	{ "DefaultKey", NULL, N_("Set as _Default"), NULL, N_("Set the selected key to be the default"),
 	  G_CALLBACK (gconf_editor_popup_window_set_as_default) },
@@ -950,7 +957,7 @@ gconf_editor_gconf_value_changed (GConfCellRenderer *cell, const gchar *path_str
 		gconf_add_recent_key (window, key);
 	}
 
-	g_free (value);
+	gconf_value_free (value);
 	g_free (key);
 	gtk_tree_path_free (path);
 }
