@@ -54,7 +54,7 @@ gconf_tree_model_search_iter_foreach (GtkTreeModel *model, GtkTreePath *path,
 		return TRUE;
 	}
 
-	if (st->res == 1) {
+	if (st->res >= 1) {
 		gtk_widget_show (GTK_WIDGET (st->output_window));
 	}
 	while (gtk_events_pending ())
@@ -88,7 +88,8 @@ gconf_tree_model_search_iter_foreach (GtkTreeModel *model, GtkTreePath *path,
 				gedit_output_window_append_line (st->output_window, key, FALSE);
 				st->res++;
 				gconf_entry_free (entry);
-				return FALSE;
+				/* After finding an entry continue the list to find other matches */
+				continue;
 			}
 		}
 
@@ -112,7 +113,7 @@ gconf_tree_model_search_iter_foreach (GtkTreeModel *model, GtkTreePath *path,
 				gedit_output_window_append_line (st->output_window, key, FALSE);
 				st->res++;
 				gconf_entry_free (entry);
-				return FALSE;
+				continue;
 			}
 		}
 		gconf_entry_free (entry);
